pub enum ReflinkMode {
Required,
Preferred,
Disabled,
}Expand description
Controls Copy-on-Write behavior when copying files into a new worktree.
Variants
Required
Fail immediately if the filesystem does not support CoW. Returns: WorktreeError::ReflinkNotSupported
Preferred
Try CoW, fall back to standard copy if unsupported. Default.
Disabled
Never attempt CoW. Always use standard copy.